@@ -9,8 +9,5 @@ from osgeo.gdal import deprecation_warn
 # Running main() must be protected that way due to use of multiprocessing on Windows:
 # https://docs.python.org/3/library/multiprocessing.html#the-spawn-and-forkserver-start-methods
 if __name__ == '__main__':
-    # Trick inspired from https://stackoverflow.com/questions/45720153/python-multiprocessing-error-attributeerror-module-main-has-no-attribute
-    # and https://bugs.python.org/issue42949
-    __spec__ = None
     deprecation_warn('gdal2tiles')
     sys.exit(main(sys.argv))
