@@ -1,7 +1,7 @@
 #!/usr/local/bin/python3.9
 # -*- coding: utf-8 -*-
 # ******************************************************************************
-#  $Id: gdal_auth.py ffccab1ee20b5151e9bd45f1a2c46245a74f1f56 2021-04-23 14:05:42 +0300 Idan Miara $
+#  $Id$
 #
 #  Project:  GDAL
 #  Purpose:  Application for Google web service authentication.
@@ -58,7 +58,7 @@ def Usage():
     return 1
 
 
-def main(argv):
+def main(argv=sys.argv):
     scope = SCOPES['ft']
     token_in = None
     command = None
