@@ -1,6 +1,6 @@
 #!/usr/local/bin/python3.9
 # ******************************************************************************
-#  $Id: gdalimport.py ffccab1ee20b5151e9bd45f1a2c46245a74f1f56 2021-04-23 14:05:42 +0300 Idan Miara $
+#  $Id$
 #
 #  Name:     gdalimport
 #  Project:  GDAL Python Interface
@@ -39,7 +39,7 @@ def progress_cb(complete, message, cb_data):
     print('%s %d' % (cb_data, complete))
 
 
-def main(argv):
+def main(argv=sys.argv):
     argv = gdal.GeneralCmdLineProcessor(argv)
     if argv is None:
         return 0
