@@ -1,7 +1,7 @@
 #!/usr/local/bin/python3.9
 # -*- coding: utf-8 -*-
 # ******************************************************************************
-#  $Id: make_fuzzer_friendly_archive.py e4fe7cc06270e5f38dfe78e6785a6bcca4e39e29 2021-04-01 21:02:04 +0300 Idan Miara $
+#  $Id$
 #
 #  Project:  GDAL
 #  Purpose:  Make fuzzer friendly archive (only works in DEBUG mode)
@@ -33,7 +33,7 @@ import os
 import sys
 
 
-def main(argv):
+def main(argv=sys.argv):
     fout = open(argv[1], "wb")
     fout.write('FUZZER_FRIENDLY_ARCHIVE\n'.encode('ascii'))
     for filename in argv[2:]:
