@@ -2,9 +2,9 @@
 #
 # -*- coding: utf-8 -*-
 # ******************************************************************************
-#  $Id: ogr_build_junction_table.py e4fe7cc06270e5f38dfe78e6785a6bcca4e39e29 2021-04-01 21:02:04 +0300 Idan Miara $
+#  $Id$
 #
-#  Name:     $Id: ogr_build_junction_table.py e4fe7cc06270e5f38dfe78e6785a6bcca4e39e29 2021-04-01 21:02:04 +0300 Idan Miara $
+#  Name:     $Id$
 #  Project:
 #  Purpose:  Build a junction table from _href fields
 #  Author:   Even Rouault, <even dot rouault at spatialys.com>
@@ -148,7 +148,7 @@ def process_layer(ds, lyr_name, bAppend, bOverwrite):
     return ret
 
 
-def main(argv):
+def main(argv=sys.argv):
     argv = ogr.GeneralCmdLineProcessor(argv)
 
     ds_name = None
@@ -206,4 +206,3 @@ def main(argv):
 
 if __name__ == '__main__':
     sys.exit(main(sys.argv))
-
