@@ -1,7 +1,7 @@
 #!/usr/local/bin/python3.9
 # -*- coding: utf-8 -*-
 ###############################################################################
-# $Id: ogr_dispatch.py ae12632821c260963247432aff038b3b7244361d 2021-04-27 23:42:00 +0300 Idan Miara $
+# $Id$
 #
 # Project:  GDAL/OGR samples
 # Purpose:  Dispatch features into layers according to the value of some fields
@@ -385,11 +385,10 @@ def ogr_dispatch(argv, progress=None, progress_arg=None):
     return 0
 
 
-def main(argv):
+def main(argv=sys.argv):
     argv = ogr.GeneralCmdLineProcessor(argv)
     return ogr_dispatch(argv[1:])
 
 
 if __name__ == '__main__':
     sys.exit(main(sys.argv))
-
