@@ -1,6 +1,6 @@
 #!/usr/local/bin/python3.9
 ###############################################################################
-# $Id: rel.py ae12632821c260963247432aff038b3b7244361d 2021-04-27 23:42:00 +0300 Idan Miara $
+# $Id$
 #
 # Project:  GDAL Python samples
 # Purpose:  Script to produce a shaded relief image from elevation data
@@ -88,7 +88,7 @@ def ParseType(typ):
     return gdal.GDT_Byte
 
 
-def main(argv):
+def main(argv=sys.argv):
     infile = None
     outfile = None
     iBand = 1	    # The first band will be converted by default
@@ -236,4 +236,3 @@ def main(argv):
 
 if __name__ == '__main__':
     sys.exit(main(sys.argv))
-
