@@ -1,7 +1,7 @@
-#!/usr/local/bin/python3.8
+#!/usr/local/bin/python3.9
 # -*- coding: utf-8 -*-
 # *****************************************************************************
-#  $Id: validate_cloud_optimized_geotiff.py e4fe7cc06270e5f38dfe78e6785a6bcca4e39e29 2021-04-01 21:02:04 +0300 Idan Miara $
+#  $Id$
 #
 #  Project:  GDAL
 #  Purpose:  Validate Cloud Optimized GeoTIFF file structure
@@ -337,7 +337,7 @@ def validate(ds, check_tiled=True, full_check=False):
     return warnings, errors, details
 
 
-def main(argv):
+def main(argv=sys.argv):
     """Return 0 in case of success, 1 for failure."""
 
     i = 1
