@@ -1,7 +1,7 @@
 #!/usr/local/bin/python3.9
 # -*- coding: utf-8 -*-
 # ******************************************************************************
-#  $Id: dump_jp2.py e4fe7cc06270e5f38dfe78e6785a6bcca4e39e29 2021-04-01 21:02:04 +0300 Idan Miara $
+#  $Id$
 #
 #  Project:  GDAL
 #  Purpose:  Dump JPEG2000 file structure
@@ -154,7 +154,7 @@ def extract_all_xml_boxes(filename, prefix):
     return 0
 
 
-def main(argv):
+def main(argv=sys.argv):
     i = 1
     out_gmljp2 = None
     out_crsdictionary = None
