@@ -1,6 +1,6 @@
 #!/usr/local/bin/python3.9
 # ******************************************************************************
-#  $Id: gcps2vec.py 4d075e0ec904e52022577b5ec56a3885f29eb9ab 2021-04-27 23:40:27 +0300 Idan Miara $
+#  $Id$
 #
 #  Project:  GDAL
 #  Purpose:  Convert GCPs to a point layer.
@@ -41,7 +41,7 @@ def Usage():
     return 1
 
 
-def main(argv):
+def main(argv=sys.argv):
     src_filename = None
     dst_filename = None
     driver_name = 'GML'
