@@ -1,6 +1,6 @@
 #!/usr/local/bin/python3.9
 # ******************************************************************************
-#  $Id: gcps2wld.py ffccab1ee20b5151e9bd45f1a2c46245a74f1f56 2021-04-23 14:05:42 +0300 Idan Miara $
+#  $Id$
 #
 #  Name:     gcps2wld
 #  Project:  GDAL Python Interface
@@ -36,7 +36,7 @@ import sys
 from osgeo import gdal
 
 
-def main(argv):
+def main(argv=sys.argv):
     if len(argv) < 2:
         print("Usage: gcps2wld.py source_file")
         return 1
