@@ -1,6 +1,6 @@
 #!/usr/local/bin/python3.9
 ###############################################################################
-# $Id: gdal_create_pdf.py e4fe7cc06270e5f38dfe78e6785a6bcca4e39e29 2021-04-01 21:02:04 +0300 Idan Miara $
+# $Id$
 #
 #  Project:  GDAL samples
 #  Purpose:  Create a PDF from a XML composition file
@@ -67,7 +67,7 @@ def gdal_create_pdf(argv):
     return 0 if out_ds else 1
 
 
-def main(argv):
+def main(argv=sys.argv):
     gdal_create_pdf(argv)
 
 
