@@ -1,7 +1,7 @@
-#!/usr/local/bin/python3.8
+#!/usr/local/bin/python3.9
 # -*- coding: utf-8 -*-
 ###############################################################################
-# $Id: gdal_ls.py e4fe7cc06270e5f38dfe78e6785a6bcca4e39e29 2021-04-01 21:02:04 +0300 Idan Miara $
+# $Id$
 #
 #  Project:  GDAL samples
 #  Purpose:  Display the list of files in a virtual directory, like /vsicurl or /vsizip
@@ -223,7 +223,7 @@ def gdal_ls(argv, fout=sys.stdout):
     return 0
 
 
-def main(argv):
+def main(argv=sys.argv):
     return gdal_ls(argv)
 
 
