@@ -1,6 +1,6 @@
 #!/usr/local/bin/python3.9
 ###############################################################################
-# $Id: gdal_mkdir.py e4fe7cc06270e5f38dfe78e6785a6bcca4e39e29 2021-04-01 21:02:04 +0300 Idan Miara $
+# $Id$
 #
 #  Project:  GDAL samples
 #  Purpose:  Create a virtual directory
@@ -65,7 +65,7 @@ def gdal_mkdir(argv, progress=None):
     return ret
 
 
-def main(argv):
+def main(argv=sys.argv):
     return gdal_mkdir(argv)
 
 
