@@ -1,6 +1,6 @@
 #!/usr/local/bin/python3.9
 # ******************************************************************************
-#  $Id: gdalident.py ffccab1ee20b5151e9bd45f1a2c46245a74f1f56 2021-04-23 14:05:42 +0300 Idan Miara $
+#  $Id$
 #
 #  Project:  GDAL
 #  Purpose:  Application to identify files by format.
@@ -65,7 +65,7 @@ def ProcessTarget(target, recursive, report_failure, filelist=None):
                 ProcessTarget(subtarget, 1, report_failure, subfilelist)
 
 
-def main(argv):
+def main(argv=sys.argv):
     recursive = 0
     report_failure = 0
     files = []
