@@ -1,6 +1,6 @@
 #!/usr/local/bin/python3.9
 # ******************************************************************************
-#  $Id: hsv_merge.py ae12632821c260963247432aff038b3b7244361d 2021-04-27 23:42:00 +0300 Idan Miara $
+#  $Id$
 #
 #  Project:  GDAL Python Interface
 #  Purpose:  Script to merge greyscale as intensity into an RGB(A) image, for
@@ -121,7 +121,7 @@ where src_color is a RGB or RGBA dataset,
     return 1
 
 
-def main(argv):
+def main(argv=sys.argv):
     argv = gdal.GeneralCmdLineProcessor(argv)
     if argv is None:
         return 0
@@ -240,4 +240,3 @@ def main(argv):
 
 if __name__ == '__main__':
     sys.exit(main(sys.argv))
-
