@@ -1,7 +1,7 @@
-#!/usr/local/bin/python3.8
+#!/usr/local/bin/python3.9
 # -*- coding: utf-8 -*-
 ###############################################################################
-# $Id: jpeg_in_tiff_extract.py e4fe7cc06270e5f38dfe78e6785a6bcca4e39e29 2021-04-01 21:02:04 +0300 Idan Miara $
+# $Id$
 #
 # Project:  GDAL/OGR samples
 # Purpose:  Extract a JPEG file from a JPEG-in-TIFF tile/strip
@@ -246,11 +246,10 @@ def jpeg_in_tiff_extract(argv):
         return 0
 
 
-def main(argv):
+def main(argv=sys.argv):
     gdal.GeneralCmdLineProcessor(argv)
     return jpeg_in_tiff_extract(argv[1:])
 
 
 if __name__ == '__main__':
     sys.exit(main(sys.argv))
-
