@@ -1,6 +1,6 @@
-#!/usr/local/bin/python3.8
+#!/usr/local/bin/python3.9
 ###############################################################################
-# $Id: load2odbc.py e4fe7cc06270e5f38dfe78e6785a6bcca4e39e29 2021-04-01 21:02:04 +0300 Idan Miara $
+# $Id$
 #
 # Project:  OGR Python samples
 # Purpose:  Load ODBC table to an ODBC datastore.  Uses direct SQL
@@ -43,7 +43,7 @@ def Usage():
     return 1
 
 
-def main(argv):
+def main(argv=sys.argv):
     extents_flag = 1
     infile = None
     odbc_dsn = None
