@@ -1,6 +1,6 @@
 #!/usr/local/bin/python3.9
 ###############################################################################
-# $Id: tigerpoly.py e4fe7cc06270e5f38dfe78e6785a6bcca4e39e29 2021-04-01 21:02:04 +0300 Idan Miara $
+# $Id$
 #
 # Project:  OGR Python samples
 # Purpose:  Assemble TIGER Polygons.
@@ -51,7 +51,7 @@ def Usage():
     return 1
 
 
-def main(argv):
+def main(argv=sys.argv):
     infile = None
     outfile = None
 
@@ -252,4 +252,3 @@ def main(argv):
 
 if __name__ == '__main__':
     sys.exit(main(sys.argv))
-
