@@ -1,7 +1,7 @@
 #!/usr/local/bin/python3.9
 # -*- coding: utf-8 -*-
 ###############################################################################
-# $Id: validate_gpkg.py d83893162b4215f023ced16148754b836d44e2d1 2022-01-31 00:12:08 +0100 Even Rouault $
+# $Id$
 #
 # Project:  GDAL/OGR
 # Purpose:  Test compliance of GeoPackage database w.r.t GeoPackage spec
@@ -1975,7 +1975,7 @@ def Usage():
     return 1
 
 
-def main(argv):
+def main(argv=sys.argv):
     filename = None
     log_msg = False
     warning_msg = True
