@@ -1,7 +1,7 @@
-#!/usr/local/bin/python3.8
+#!/usr/local/bin/python3.9
 # -*- coding: utf-8 -*-
 # ******************************************************************************
-#  $Id: validate_jp2.py b55a33407a80673ec314b165c82f47dd02e9dc9c 2020-04-27 20:37:55 +0200 Even Rouault $
+#  $Id$
 #
 #  Project:  GDAL
 #  Purpose:  Validate JPEG2000 file structure
@@ -773,7 +773,7 @@ def validate(filename, oidoc, inspire_tg, expected_gmljp2, ogc_schemas_location,
                         break
                     asoc = int(asoc)
                     if inspire_tg and asoc == 0:
-                        if not(typ == 1 or typ == 2):
+                        if not (typ == 1 or typ == 2):
                             error_report.EmitError('GENERAL', 'cdef.asoc[%d] = %d whereas cdef.typ[%d] = %d' % (i, asoc, i, typ))
                         if asoc_whole_used:
                             error_report.EmitError('GENERAL', 'cdef.asoc[%d] = %d is invalid since another band has already been associated to whole image' % (i, asoc))
@@ -1194,7 +1194,7 @@ def validate(filename, oidoc, inspire_tg, expected_gmljp2, ogc_schemas_location,
     return error_report
 
 
-def main():
+def main(argv=sys.argv):
     i = 1
     filename = None
     oidoc = None
@@ -1202,30 +1202,30 @@ def main():
     inspire_tg = False
     expected_gmljp2 = False
     datatype = 'imagery'
-    while i < len(sys.argv):
-        if sys.argv[i] == "-oidoc":
-            if i >= len(sys.argv) - 1:
+    while i < len(argv):
+        if argv[i] == "-oidoc":
+            if i >= len(argv) - 1:
                 return Usage()
-            oidoc = sys.argv[i + 1]
+            oidoc = argv[i + 1]
             i = i + 1
-        elif sys.argv[i] == "-ogc_schemas_location":
-            if i >= len(sys.argv) - 1:
+        elif argv[i] == "-ogc_schemas_location":
+            if i >= len(argv) - 1:
                 return Usage()
-            ogc_schemas_location = sys.argv[i + 1]
+            ogc_schemas_location = argv[i + 1]
             i = i + 1
-        elif sys.argv[i] == "-datatype":
-            if i >= len(sys.argv) - 1:
+        elif argv[i] == "-datatype":
+            if i >= len(argv) - 1:
                 return Usage()
-            datatype = sys.argv[i + 1]
+            datatype = argv[i + 1]
             i = i + 1
-        elif sys.argv[i] == "-inspire_tg":
+        elif argv[i] == "-inspire_tg":
             inspire_tg = True
-        elif sys.argv[i] == "-expected_gmljp2":
+        elif argv[i] == "-expected_gmljp2":
             expected_gmljp2 = True
-        elif sys.argv[i][0] == '-':
+        elif argv[i][0] == '-':
             return Usage()
         elif filename is None:
-            filename = sys.argv[i]
+            filename = argv[i]
         else:
             return Usage()
 
@@ -1256,4 +1256,4 @@ def main():
 
 
 if __name__ == '__main__':
-    sys.exit(main())
+    sys.exit(main(sys.argv))
