@@ -1,6 +1,6 @@
 #!/usr/local/bin/python3.9
 ###############################################################################
-# $Id: vec_tr.py e4fe7cc06270e5f38dfe78e6785a6bcca4e39e29 2021-04-01 21:02:04 +0300 Idan Miara $
+# $Id$
 #
 # Project:  OGR Python samples
 # Purpose:  Apply a transformation to all OGR geometries.
@@ -76,7 +76,7 @@ def Usage():
     return 1
 
 
-def main(argv):
+def main(argv=sys.argv):
     infile = None
     outfile = None
     layer_name = None
